summaryrefslogtreecommitdiffstats
path: root/generic/tkMenu.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2021-12-21 13:02:01 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2021-12-21 13:02:01 (GMT)
commitfbc72eac8c4bf3a9b9b81257b08dc6a5640b7dbf (patch)
treeb1cbf445745737ee57b0403a87a3fcd4272502ca /generic/tkMenu.c
parentaec52e5a9a78885e9fc2a8210e8e06bd2fad401e (diff)
downloadtk-fbc72eac8c4bf3a9b9b81257b08dc6a5640b7dbf.zip
tk-fbc72eac8c4bf3a9b9b81257b08dc6a5640b7dbf.tar.gz
tk-fbc72eac8c4bf3a9b9b81257b08dc6a5640b7dbf.tar.bz2
TIP #606 implementation. TODO: documentation
Diffstat (limited to 'generic/tkMenu.c')
-rw-r--r--generic/tkMenu.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/generic/tkMenu.c b/generic/tkMenu.c
index 174736a..8958c51 100644
--- a/generic/tkMenu.c
+++ b/generic/tkMenu.c
@@ -580,14 +580,14 @@ Tk_MenuObjCmd(
while (topLevelListPtr != NULL) {
/*
* Need to get the next pointer first. TkSetWindowMenuBar changes
* the list, so that the next pointer is different after calling
* it.
*/
nextPtr = topLevelListPtr->nextPtr;
listtkwin = topLevelListPtr->tkwin;
- TkSetWindowMenuBar(menuPtr->interp, listtkwin,
+ Tk_SetWindowMenuBar(menuPtr->interp, listtkwin,
Tk_PathName(menuPtr->tkwin), Tk_PathName(menuPtr->tkwin));
topLevelListPtr = nextPtr;
}
@@ -3139,7 +3139,7 @@ TkNewMenuName(
/*
*----------------------------------------------------------------------
*
- * TkSetWindowMenuBar --
+ * Tk_SetWindowMenuBar --
*
* Associates a menu with a window. Called by ConfigureFrame in in
* response to a "-menu .foo" configuration option for a top level.
@@ -3155,7 +3155,7 @@ TkNewMenuName(
*/
void
-TkSetWindowMenuBar(
+Tk_SetWindowMenuBar(
Tcl_Interp *interp, /* The interpreter the toplevel lives in. */
Tk_Window tkwin, /* The toplevel window. */
const char *oldMenuName, /* The name of the menubar previously set in
@@ -3297,7 +3297,7 @@ TkSetWindowMenuBar(
} else {
TkpSetWindowMenuBar(tkwin, NULL);
}
- TkpSetMainMenubar(interp, tkwin, menuName);
+ Tk_SetMainMenubar(interp, tkwin, menuName);
}
/*
@@ -580,14 +580,14 @@ Tk_MenuObjCmd(
while (topLevelListPtr != NULL) {
/*
- * Need to get the next pointer first. TkSetWindowMenuBar changes
+ * Need to get the next pointer first. Tk_SetWindowMenuBar changes
* the list, so that the next pointer is different after calling
* it.